// -------------------------------------------------------------- -*- Java -*- 
//  Freeciv - Copyright (C) 1996 - A Kjeldberg, L Gregersen, P Unold
// --------------------------------------------------------------------------- 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// --------------------------------------------------------------------------- 
// FILE NAME        : MapKeyListener.java
// DESCRIPTION      : The listener for the map
// DATE             : 08/04/2002
// AUTHORS          : Olivier Leprince
// PROJECT          : Freeciv Java 
// CATEGORY         : Map part
// --------------------------------------------------------------------------- 

package org.freeciv.client.map;

import java.awt.event.*;

import org.freeciv.net.PktMoveUnit;
import org.freeciv.common.Map;
import org.freeciv.common.Unit;
import org.freeciv.client.Client;


/**
 * Listener for Map Key events
 * @author Olivier Leprince
 */
public class MapKeyListener extends KeyAdapter
{

  /** The client */
  private Client m_client;

  /** The map */
  private Map m_map;;

  public MapKeyListener(Client client, Map map)
  {
    m_client = client;
    m_map = map;
  }

  public void keyPressed(KeyEvent e)
  {
    int dx=0, dy=0;

    int code = e.getKeyCode();
    if (code==KeyEvent.VK_UP || code==KeyEvent.VK_NUMPAD8)
    { dy = -1; }
    else if (code==KeyEvent.VK_DOWN || code==KeyEvent.VK_NUMPAD2)
    { dy = 1; }
    else if (code==KeyEvent.VK_LEFT || code==KeyEvent.VK_NUMPAD4)
    { dx = -1; }
    else if (code==KeyEvent.VK_RIGHT || code==KeyEvent.VK_NUMPAD6)
    { dx = 1; }
    else if (code==KeyEvent.VK_NUMPAD9)
    { dx = 1; dy = -1; }
    else if (code==KeyEvent.VK_NUMPAD7)
    { dx = -1; dy = -1; }
    else if (code==KeyEvent.VK_NUMPAD3)
    { dx = 1; dy = 1; }
    else if (code==KeyEvent.VK_NUMPAD1)
    { dx = -1; dy = 1; }

    // Take the focused unit
    Unit u = m_client.getUnitInFocus();
    if (u!=null)
    {
      PktMoveUnit pkt = new PktMoveUnit();
      pkt.unitId = u.getId();
      pkt.nx = m_map.adjustX(u.getX()+dx);
      pkt.ny = m_map.adjustY(u.getY()+dy);
      m_client.sendToServer(pkt);
    }
  }

}
